@@ -67,5 +67,5 @@ class WSDLService(object):
             }
         }
         for port in self.ports():
-            config[access_point][port] = f"{port}.xml"
+            config[access_point][port] = "{}.xml".format(port)
         return config
